#!/usr/bin/env bash
# Install all dependencies required to install the MICADO pipeline
# on a conda installation.
# E.g. to be used on the MicadoWISE CI.

# https://betterdev.blog/minimal-safe-bash-script-template/
set -Eeuo pipefail

script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &>/dev/null && pwd -P)

# Set environment variables.
source "${script_dir}/set_environment.sh"

echo "Downloading files to ${TOINSTALLDIR}"
echo "Installing software to ${ESOPIPELINE}"

mkdir -p "${TOINSTALLDIR}"
mkdir -p "${ESOPIPELINE}"

pushd "${TOINSTALLDIR}" || exit

# TODO: check for curl, fftw

echo "Installing CFITSIO"
wget https://ftp.eso.org/pub/dfs/pipelines/libraries/cfitsio/cfitsio-3.49.tar.gz
tar -xvf cfitsio-3.49.tar.gz
pushd cfitsio-3.49 || exit
# Disable curl as it is not necessary and causes problems on some operating systems.
./configure --prefix="${ESOPIPELINE}" --enable-reentrant --disable-curl
make
make install
popd || exit

echo "Installing WCSLIB"
wget https://ftp.eso.org/pub/dfs/pipelines/libraries/wcslib/wcslib-7.6.tar.bz2
tar -xvf wcslib-7.6.tar.bz2
pushd wcslib-7.6 || exit
./configure --prefix=$WCSDIR --with-cfitsiolib="$CFITSIODIR/lib" --with-cfitsioinc="$CFITSIODIR/include"
make
make install
pushd || exit

echo "Installing CPL"
wget https://ftp.eso.org/pub/dfs/pipelines/libraries/cpl/cpl-7.1.4.tar.gz
tar -xvf cpl-7.1.4.tar.gz
pushd cpl-7.1.4 || exit
# Disable FFTW, because it is not necessary and can cause problems on some operating systems.
./configure --prefix=$CPLDIR --disable-fft
make
make install
popd || exit

echo "Installing ESOREX"
wget https://ftp.eso.org/pub/dfs/pipelines/libraries/esorex/esorex-3.13.5.tar.gz
tar -xvf esorex-3.13.5.tar.gz
pushd esorex-3.13.5 || exit
LD_LIBRARY_PATH="$ESOPIPELINE/lib:$(dirname $(which gcc))/../lib" LDFLAGS="-L$ESOPIPELINE/lib" LIBS="-lcext -lcfitsio -lgomp" ./configure --prefix=$ESOPIPELINE
make
make install
popd || exit

popd || exit

esorex --create-config
