# -*- coding: utf-8 -*-
"""Recipes."""

import re
from typing import Type

from micado.main.MObject import MObject


class RecipeExtra(MObject):
    """A Recipe.

    Recipe instances store all process parameters of the recipe.
    """

    @classmethod
    def name_eso(cls):
        """Name according to ESO standards.

        E.g. McdDetDark -> mcd_det_dark.
        """
        # From https://stackoverflow.com/a/1176023/2097
        n1 = cls.__name__
        n2 = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", n1)
        n3 = re.sub("([a-z0-9])([A-Z])", r"\1_\2", n2).lower()
        n4 = n3.replace("mcd_", "micado_")
        return n4

    @classmethod
    def get_parameters_c(cls: Type["RecipeExtra"]):
        """Get full set of parameters for this Recipe."""
        step = cls.process.prop_type
        params = []
        while step is not None:
            params += step.get_parameters()
            step = step.get_previous_step()

        return params

    @classmethod
    def get_inputdata(cls):
        """Input data, first is main input."""
        step = cls.process.prop_type
        inputdata = []
        while step:
            inputdata = step.get_other_inputdata_full() + inputdata
            step = step.get_previous_step()

        return inputdata

    @classmethod
    def get_all_steps(cls):
        """All recipe steps."""
        step = cls.process.prop_type
        steps = []
        while step:
            steps.append(step)
            step = step.get_previous_step()

        return steps
