# -*- coding: utf-8 -*-
"""Some tests for the Detector class.

The Detector class is one of the
simplest MDBObject classes, while having some complexity, so this also
tests the MDBObjects.
"""
import pytest
from micado.main.commonwrapper import Env
from micado.hardware.DarkCurrent import DarkCurrent

from micado.hardware.Detector import Detector
from micado.hardware.DetectorArray import DetectorArray
from micado.hardware.LinearityCurve import LinearityCurve
from micado.hardware.QuantumEfficiencyCurve import QuantumEfficiencyCurve
from micado.hardware.ShotNoise import ShotNoise
from micado.hardware.SummedExposure import SummedExposure


def generate_detectorarray(
    dark: float = 2.0, hw: float = 0.24, n_det=1
) -> DetectorArray:
    """Generate a DetectorArray.

    Args:
        dark: Value of the Dark Current.
        hw: Something with size of the detector TODO rename.
        n_det: Number of detectors.
    """
    my_detector_list = [
        Detector(id=f"det{i+1}", x_cen=400 * i, xhw=hw, yhw=hw) for i in range(n_det)
    ]
    my_dark_current = DarkCurrent(value=dark)
    my_shot_noise = ShotNoise(state=1)
    return DetectorArray(
        name="test_detector",
        detector_array_list=my_detector_list,
        dark_current=my_dark_current,
        shot_noise=my_shot_noise,
        qecurve=QuantumEfficiencyCurve(realfilename="QE_detector_H2RG.dat"),
        linearity=LinearityCurve(realfilename="FPA_linearity.dat"),
        exposure_action=SummedExposure(),
    )


def test_extra_parameters():
    """Test whether there is an error when extra parameters are specified."""
    Env["use_python_logging"] = True

    with pytest.raises(AttributeError):
        _ = Detector(
            angle=4.0,
            doesnotexist=5.0,
        )


def test_detectorarray_single():
    """Test construction of DetectorArray."""
    _ = generate_detectorarray()
