# -*- coding: utf-8 -*-
"""Create OBX files from Python."""

from pathlib import Path

from micado.main.ObservingBlock import ObservingBlock
from micado.templates.MicadoImgCalDark import MicadoImgCalDark

PATH_OBX = Path(__file__).resolve().parent.parent / "test" / "functional"


def create_dark_ob():
    """Create an ObservingBlock for a Dark exposure."""
    return ObservingBlock(
        name="MyDarkTest",
        instrument="MICADO",
        target="empty_sky",
        templates=[MicadoImgCalDark(det__dit=1)],
    )


def main():
    """Generate OBX files.

    OBX files are stored in the test directory because they can then also
    be used for testing.
    """
    ob_dark = create_dark_ob()
    with open(PATH_OBX / f"{ob_dark.templates[0].__class__.name_eso()}.obx", "w") as f:
        f.write(ob_dark.obx)


if __name__ == "__main__":
    main()
